@@ -7,7 +7,6 @@ import requests
 import time
 import datetime
 import previsionio as pio
-import os
 from functools import lru_cache
 from dateutil import parser
 
@@ -77,7 +76,7 @@ class BaseExperimentVersion(ApiResource):
         return data
 
     @classmethod
-    def new(cls, experiment_id, data) -> 'BaseExperimentVersion':
+    def _new(cls, experiment_id, data) -> 'BaseExperimentVersion':
         endpoint = f'/experiments/{experiment_id}/versions'
         response = client.request(endpoint,
                                   method=requests.post,
@@ -100,17 +99,20 @@ class BaseExperimentVersion(ApiResource):
         return self
 
     @classmethod
-    def _fit(cls, experiment_id: str,
-             description: str = None,
-             parent_version: str = None,
-             **kwargs) -> 'BaseExperimentVersion':
+    def _fit(
+        cls,
+        experiment_id: str,
+        description: str = None,
+        parent_version: str = None,
+        **kwargs,
+    ) -> 'BaseExperimentVersion':
 
         experiment_version_creation_data = cls._build_experiment_version_creation_data(
             description,
             parent_version=parent_version,
             **kwargs,
         )
-        experiment_version_draft = cls.new(experiment_id, experiment_version_creation_data)
+        experiment_version_draft = cls._new(experiment_id, experiment_version_creation_data)
         experiment_version_draft._update_draft(**kwargs)
         experiment_version = experiment_version_draft._confirm()
 
@@ -162,7 +164,7 @@ class BaseExperimentVersion(ApiResource):
 
     @property
     def models(self):
-        """Get the list of models generated for the current use case. Only the models that
+        """Get the list of models generated for the current experiment version. Only the models that
         are done training are retrieved.
 
         Returns:
@@ -184,7 +186,7 @@ class BaseExperimentVersion(ApiResource):
         Returns:
             :class:`.Dataset`: Associated training dataset
         """
-        return Dataset.from_id(_id=self.dataset_id)
+        return self.dataset
 
     @property
     @lru_cache()
@@ -198,8 +200,8 @@ class BaseExperimentVersion(ApiResource):
         response = client.request(endpoint=end_point,
                                   method=requests.get,
                                   message_prefix='Experiment schema')
-        uc_schema = json.loads(response.content.decode('utf-8'))
-        return uc_schema
+        schema = json.loads(response.content.decode('utf-8'))
+        return schema
 
     @property
     def best_model(self):
@@ -416,24 +418,6 @@ class BaseExperimentVersion(ApiResource):
         except KeyError:
             return float('inf')
 
-    def _save_json(self):
-        raise NotImplementedError
-
-    def save(self, directory: str = '.'):
-        version_dict = self._save_json()
-        with open(os.path.join(directory, self.name) + '.pio', 'w') as f:
-            json.dump(version_dict, f)
-
-    @classmethod
-    def _load(cls, pio_file: str) -> Dict:
-        with open(pio_file, 'r') as f:
-            mdl = json.load(f)
-        uc = cls._from_id(mdl['_id'])
-        # TODO check holdout_dataset in experiment_version_params
-        # if mdl['experiment_version_params'].get('holdout_dataset_id'):
-        #     uc.holdout_dataset = mdl['experiment_version_params'].get('holdout_dataset_id')[0]
-        return uc
-
 
 class ClassicExperimentVersion(BaseExperimentVersion):
 
@@ -446,8 +430,7 @@ class ClassicExperimentVersion(BaseExperimentVersion):
     def _update_from_dict(self, **experiment_version_info):
         super()._update_from_dict(**experiment_version_info)
 
-        dataset_id: str = experiment_version_info['dataset_id']
-        self.dataset: Dataset = Dataset.from_id(dataset_id)
+        self.dataset_id: str = experiment_version_info['dataset_id']
 
         experiment_params = experiment_version_info['experiment_version_params']
         self.column_config = ColumnConfig(target_column=experiment_params.get('target_column'),
@@ -461,11 +444,7 @@ class ClassicExperimentVersion(BaseExperimentVersion):
 
         self.metric: str = experiment_params['metric']
 
-        holdout_dataset_id: Union[str, None] = experiment_version_info.get('holdout_dataset_id', None)
-        if holdout_dataset_id is not None:
-            self.holdout_dataset: Dataset = Dataset.from_id(holdout_dataset_id)
-        else:
-            self.holdout_dataset = None
+        self.holdout_dataset_id: Union[str, None] = experiment_version_info.get('holdout_dataset_id', None)
 
         self.training_config = TrainingConfig(
             profile=Profile(experiment_params.get('profile')),
@@ -476,6 +455,24 @@ class ClassicExperimentVersion(BaseExperimentVersion):
             feature_time_seconds=experiment_params.get('features_selection_time', 3600),
             feature_number_kept=experiment_params.get('features_selection_count', None))
 
+    @property
+    def dataset(self) -> Dataset:
+        """ Get the :class:`.Dataset` object corresponding to the training dataset of this experiment version.
+
+        Returns:
+            :class:`.Dataset`: Associated training dataset
+        """
+        return Dataset.from_id(self.dataset_id)
+
+    @property
+    def holdout_dataset(self) -> Union[Dataset, None]:
+        """ Get the :class:`.Dataset` object corresponding to the holdout dataset of this experiment version.
+
+        Returns:
+            :class:`.Dataset`: Associated holdout dataset
+        """
+        return Dataset.from_id(self.holdout_dataset_id) if self.holdout_dataset_id is not None else None
+
     @property
     def advanced_models_list(self) -> List[AdvancedModel]:
         """ Get the list of selected advanced models in the experiment.
