@@ -16,7 +16,7 @@ from .dataset import Dataset, DatasetImages
 from .connector import (Connector, SQLConnector, FTPConnector, SFTPConnector,
                         S3Connector, GCPConnector, GCloud)
 from .supervised import Supervised
-from .external_models import ExternalExperimentVersion
+from .external_experiment_version import ExternalExperimentVersion
 from .timeseries import TimeSeries, TimeWindow
 from .text_similarity import (DescriptionsColumnConfig, ListModelsParameters, QueriesColumnConfig,
                               TextSimilarity, TextSimilarityLang)
@@ -237,7 +237,7 @@ class Project(ApiResource, UniqueResourceMixin):
 
         .. note::
 
-            To start a new use case on a dataset, it has to be already
+            To start a new experiment version on a dataset, it has to be already
             registred in your workspace.
 
         Args:
@@ -285,7 +285,7 @@ class Project(ApiResource, UniqueResourceMixin):
 
         .. note::
 
-            To start a new use case on a dataset image, it has to be already
+            To start a new experiment version on a dataset image, it has to be already
             registred in your workspace.
 
         Args:
@@ -507,14 +507,16 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         return Exporter.list(self._id, all=all)
 
-    def fit_regression(self,
-                       experiment_name: str,
-                       dataset: Dataset,
-                       column_config: ColumnConfig,
-                       metric: metrics.Regression = metrics.Regression.RMSE,
-                       holdout_dataset=None,
-                       training_config=TrainingConfig(),
-                       experiment_version_description: str = None):
+    def fit_regression(
+        self,
+        experiment_name: str,
+        dataset: Dataset,
+        column_config: ColumnConfig,
+        metric: metrics.Regression = metrics.Regression.RMSE,
+        holdout_dataset=None,
+        training_config=TrainingConfig(),
+        experiment_version_description: str = None,
+    ) -> Supervised:
         """ Start a tabular regression experiment version training
 
         Args:
@@ -525,7 +527,7 @@ class Project(ApiResource, UniqueResourceMixin):
                 (see the documentation of the :class:`.ColumnConfig` resource for more details
                 on each possible column types)
             metric (:class:`.metrics.Regression`, optional): Specific metric to use for the experiment
-                (default: ``None``)
+                (default: ``metrics.Regression.RMSE``)
             holdout_dataset (:class:`.Dataset`, optional): Reference to a dataset object to
                 use as a holdout dataset (default: ``None``)
             training_config (:class:`.TrainingConfig`): Specific training configuration
@@ -548,14 +550,16 @@ class Project(ApiResource, UniqueResourceMixin):
             description=experiment_version_description,
         )
 
-    def fit_classification(self,
-                           experiment_name: str,
-                           dataset: Dataset,
-                           column_config: ColumnConfig,
-                           metric: metrics.Classification = metrics.Classification.AUC,
-                           holdout_dataset=None,
-                           training_config=TrainingConfig(),
-                           experiment_version_description: str = None):
+    def fit_classification(
+        self,
+        experiment_name: str,
+        dataset: Dataset,
+        column_config: ColumnConfig,
+        metric: metrics.Classification = metrics.Classification.AUC,
+        holdout_dataset=None,
+        training_config=TrainingConfig(),
+        experiment_version_description: str = None,
+    ) -> Supervised:
         """ Start a tabular classification experiment version training
 
         Args:
@@ -566,7 +570,7 @@ class Project(ApiResource, UniqueResourceMixin):
                 (see the documentation of the :class:`.ColumnConfig` resource for more details
                 on each possible column types)
             metric (:class:`.metrics.Classification`, optional): Specific metric to use for the experiment
-                (default: ``None``)
+                (default: ``metrics.Classification.AUC``)
             holdout_dataset (:class:`.Dataset`, optional): Reference to a dataset object to
                 use as a holdout dataset (default: ``None``)
             training_config (:class:`.TrainingConfig`): Specific training configuration
@@ -589,14 +593,16 @@ class Project(ApiResource, UniqueResourceMixin):
             description=experiment_version_description,
         )
 
-    def fit_multiclassification(self,
-                                experiment_name: str,
-                                dataset: Dataset,
-                                column_config: ColumnConfig,
-                                metric: metrics.MultiClassification = metrics.MultiClassification.log_loss,
-                                holdout_dataset=None,
-                                training_config=TrainingConfig(),
-                                experiment_version_description: str = None):
+    def fit_multiclassification(
+        self,
+        experiment_name: str,
+        dataset: Dataset,
+        column_config: ColumnConfig,
+        metric: metrics.MultiClassification = metrics.MultiClassification.log_loss,
+        holdout_dataset=None,
+        training_config=TrainingConfig(),
+        experiment_version_description: str = None,
+    ) -> Supervised:
         """ Start a tabular multiclassification experiment version training
 
         Args:
@@ -607,7 +613,7 @@ class Project(ApiResource, UniqueResourceMixin):
                 (see the documentation of the :class:`.ColumnConfig` resource for more details
                 on each possible column types)
             metric (:class:`.metrics.MultiClassification`, optional): Specific metric to use for the experiment
-                (default: ``None``)
+                (default: ``metrics.MultiClassification.log_loss``)
             holdout_dataset (:class:`.Dataset`, optional): Reference to a dataset object to
                 use as a holdout dataset (default: ``None``)
             training_config (:class:`.TrainingConfig`): Specific training configuration
@@ -630,24 +636,30 @@ class Project(ApiResource, UniqueResourceMixin):
             description=experiment_version_description,
         )
 
-    def fit_image_regression(self,
-                             experiment_name: str,
-                             dataset: Tuple[Dataset, DatasetImages],
-                             column_config: ColumnConfig,
-                             metric: metrics.Regression = metrics.Regression.RMSE,
-                             holdout_dataset=None,
-                             training_config=TrainingConfig(),
-                             experiment_version_description: str = None):
+    def fit_image_regression(
+        self,
+        experiment_name: str,
+        dataset: Dataset,
+        dataset_images: DatasetImages,
+        column_config: ColumnConfig,
+        metric: metrics.Regression = metrics.Regression.RMSE,
+        holdout_dataset=None,
+        training_config=TrainingConfig(),
+        experiment_version_description: str = None,
+    ) -> Supervised:
         """ Start an image regression experiment version training
 
         Args:
             experiment_name (str): Name of the experiment to create
-            dataset (:class:`.Dataset`, :class:`.DatasetImages`): Reference to the datasets
-                objects to use for as training datasets
+            dataset (:class:`.Dataset`): Reference to the dataset
+                object to use for as training dataset
+            dataset_images (:class:`.DatasetImages`): Reference to the images dataset
+                object to use for as training dataset
             column_config (:class:`.ColumnConfig`): Column configuration for the experiment
                 (see the documentation of the :class:`.ColumnConfig` resource for more details
                 on each possible column types)
             metric (:class:`.metrics.Regression`, optional): Specific metric to use for the experiment
+                (default: ``metrics.Regression.RMSE``)
             holdout_dataset (:class:`.Dataset`, optional): Reference to a dataset object to
                 use as a holdout dataset (default: ``None``)
             training_config (:class:`.TrainingConfig`): Specific training configuration
@@ -660,6 +672,7 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Images,
                                     TypeProblem.Regression)
+        dataset = (dataset, dataset_images)
         return Supervised._fit(
             experiment.id,
             dataset,
@@ -670,25 +683,30 @@ class Project(ApiResource, UniqueResourceMixin):
             description=experiment_version_description,
         )
 
-    def fit_image_classification(self,
-                                 experiment_name: str,
-                                 dataset: Tuple[Dataset, DatasetImages],
-                                 column_config: ColumnConfig,
-                                 metric: metrics.Classification = metrics.Classification.AUC,
-                                 holdout_dataset=None,
-                                 training_config=TrainingConfig(),
-                                 experiment_version_description: str = None):
+    def fit_image_classification(
+        self,
+        experiment_name: str,
+        dataset: Dataset,
+        dataset_images: DatasetImages,
+        column_config: ColumnConfig,
+        metric: metrics.Classification = metrics.Classification.AUC,
+        holdout_dataset=None,
+        training_config=TrainingConfig(),
+        experiment_version_description: str = None
+    ) -> Supervised:
         """ Start an image classification experiment version training
 
         Args:
             experiment_name (str): Name of the experiment to create
-            dataset (:class:`.Dataset`, :class:`.DatasetImages`): Reference to the datasets
-                objects to use for as training datasets
+            dataset (:class:`.Dataset`): Reference to the dataset
+                object to use for as training dataset
+            dataset_images (:class:`.DatasetImages`): Reference to the images dataset
+                object to use for as training dataset
             column_config (:class:`.ColumnConfig`): Column configuration for the experiment
                 (see the documentation of the :class:`.ColumnConfig` resource for more details
                 on each possible column types)
             metric (:class:`.metrics.Classification`, optional): Specific metric to use for the experiment
-                (default: ``None``)
+                (default: ``metrics.Classification.AUC``)
             holdout_dataset (:class:`.Dataset`, optional): Reference to a dataset object to
                 use as a holdout dataset (default: ``None``)
             training_config (:class:`.TrainingConfig`): Specific training configuration
@@ -701,6 +719,7 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Images,
                                     TypeProblem.Classification)
+        dataset = (dataset, dataset_images)
         return Supervised._fit(
             experiment.id,
             dataset,
@@ -711,20 +730,25 @@ class Project(ApiResource, UniqueResourceMixin):
             description=experiment_version_description,
         )
 
-    def fit_image_multiclassification(self,
-                                      experiment_name: str,
-                                      dataset: Tuple[Dataset, DatasetImages],
-                                      column_config: ColumnConfig,
-                                      metric: metrics.MultiClassification = metrics.MultiClassification.log_loss,
-                                      holdout_dataset=None,
-                                      training_config=TrainingConfig(),
-                                      experiment_version_description: str = None):
+    def fit_image_multiclassification(
+        self,
+        experiment_name: str,
+        dataset: Dataset,
+        dataset_images: DatasetImages,
+        column_config: ColumnConfig,
+        metric: metrics.MultiClassification = metrics.MultiClassification.log_loss,
+        holdout_dataset=None,
+        training_config=TrainingConfig(),
+        experiment_version_description: str = None,
+    ) -> Supervised:
         """ Start an image multiclassification experiment version training
 
         Args:
             experiment_name (str): Name of the experiment to create
-            dataset (:class:`.Dataset`, :class:`.DatasetImages`): Reference to the datasets
-                objects to use for as training datasets
+            dataset (:class:`.Dataset`): Reference to the dataset
+                object to use for as training dataset
+            dataset_images (:class:`.DatasetImages`): Reference to the images dataset
+                object to use for as training dataset
             column_config (:class:`.ColumnConfig`): Column configuration for the experiment
                 (see the documentation of the :class:`.ColumnConfig` resource for more details
                 on each possible column types)
@@ -742,6 +766,7 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Images,
                                     TypeProblem.MultiClassification)
+        dataset = (dataset, dataset_images)
         return Supervised._fit(
             experiment.id,
             dataset,
@@ -774,8 +799,8 @@ class Project(ApiResource, UniqueResourceMixin):
                 on each possible column types)
             time_window (:class:`.TimeWindow`): Time configuration
                 (see the documentation of the :class:`.TimeWindow` resource for more details)
-            metric (:class:`.metrics.Regression`, optional): Specific metric to use for the experiment (default:
-                ``metrics.Regression.RMSE``)
+            metric (:class:`.metrics.Regression`, optional): Specific metric to use for the experiment
+                (default: ``metrics.Regression.RMSE``)
             holdout_dataset (:class:`.Dataset`, optional): Reference to a dataset object to
                 use as a holdout dataset (default: ``None``)
             training_config (:class:`.TrainingConfig`): Specific training configuration
@@ -799,17 +824,19 @@ class Project(ApiResource, UniqueResourceMixin):
             description=experiment_version_description,
         )
 
-    def fit_text_similarity(self,
-                            experiment_name: str,
-                            dataset: Dataset,
-                            description_column_config: DescriptionsColumnConfig,
-                            metric: metrics.TextSimilarity = metrics.TextSimilarity.accuracy_at_k,
-                            top_k: int = 10,
-                            lang: TextSimilarityLang = TextSimilarityLang.Auto,
-                            queries_dataset: Dataset = None,
-                            queries_column_config: QueriesColumnConfig = None,
-                            models_parameters: ListModelsParameters = ListModelsParameters(),
-                            experiment_version_description: str = None):
+    def fit_text_similarity(
+        self,
+        experiment_name: str,
+        dataset: Dataset,
+        description_column_config: DescriptionsColumnConfig,
+        metric: metrics.TextSimilarity = metrics.TextSimilarity.accuracy_at_k,
+        top_k: int = 10,
+        lang: TextSimilarityLang = TextSimilarityLang.Auto,
+        queries_dataset: Dataset = None,
+        queries_column_config: QueriesColumnConfig = None,
+        models_parameters: ListModelsParameters = ListModelsParameters(),
+        experiment_version_description: str = None,
+    ) -> TextSimilarity:
         """ Start a text similarity experiment version training with a specific training configuration.
 
         Args:
@@ -819,8 +846,10 @@ class Project(ApiResource, UniqueResourceMixin):
                 (see the documentation of the :class:`.DescriptionsColumnConfig` resource for more details
                 on each possible column types)
             metric (:class:`.metrics.TextSimilarity`, optional): Specific metric to use for the experiment
-                (default: ``accuracy_at_k``)
+                (default: ``metrics.TextSimilarity.accuracy_at_k``)
             top_k (int, optional): top_k (default: ``10``)
+            lang (:class:`.TextSimilarityLang`, optional): lang of the training dataset
+                (default: ``.TextSimilarityLang.Auto``)
             queries_dataset (:class:`.Dataset`, optional): Reference to a dataset object to
                 use as a queries dataset (default: ``None``)
             queries_column_config (:class:`.QueriesColumnConfig`): Queries column configuration
@@ -848,26 +877,30 @@ class Project(ApiResource, UniqueResourceMixin):
             models_parameters=models_parameters
         )
 
-    def create_external_regression(self,
-                                   experiment_name: str,
-                                   holdout_dataset: Dataset,
-                                   target_column: str,
-                                   external_models: List[Tuple],
-                                   metric: metrics.Regression = metrics.Regression.RMSE,
-                                   dataset: Dataset = None,
-                                   experiment_version_description: str = None) -> ExternalExperimentVersion:
+    def create_external_regression(
+        self,
+        experiment_name: str,
+        holdout_dataset: Dataset,
+        target_column: str,
+        external_models: List[Tuple],
+        metric: metrics.Regression = metrics.Regression.RMSE,
+        dataset: Dataset = None,
+        experiment_version_description: str = None,
+    ) -> ExternalExperimentVersion:
         """ Create a tabular regression experiment version from external models
 
         Args:
             experiment_name (str): Name of the experiment to create
             holdout_dataset (:class:`.Dataset`): Reference to the holdout dataset object to use for as holdout dataset
-            target_column: The name of the target column for this experiment version
-            external_models (list(tuple)): the external models to add in the experiment version to create
+            target_column (str): The name of the target column for this experiment version
+            external_models (list(tuple)): The external models to add in the experiment version to create.
                 Each tuple contains 3 items describing an external model as follows:
-                - name of the model
-                - a path to the model in onnx format
-                - a path to a yaml file containing metadata about the model
-            metric (str, optional): Specific metric to use for the experiment (default: ``rmse``)
+
+                    1) The name you want to give to the model
+                    2) The path to the model in onnx format
+                    3) The path to a yaml file containing metadata about the model
+            metric (:class:`.metrics.Regression`, optional): Specific metric to use for the experiment
+                (default: ``metrics.Regression.RMSE``)
             dataset (:class:`.Dataset`, optional): Reference to the dataset object that
                 has been used to train the model (default: ``None``)
             experiment_version_description (str): Description of the experiment version to create
@@ -877,7 +910,8 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         if len(external_models) == 0:
             raise PrevisionException('You must provide at least one external model')
-        experiment = Experiment.new(self._id, 'external', experiment_name, DataType.Tabular, TypeProblem.Regression)
+        experiment = Experiment.new(self._id, 'external', experiment_name, DataType.Tabular,
+                                    TypeProblem.Regression)
         return ExternalExperimentVersion._fit(
             experiment.id,
             holdout_dataset,
@@ -888,26 +922,30 @@ class Project(ApiResource, UniqueResourceMixin):
             description=experiment_version_description,
         )
 
-    def create_external_classification(self,
-                                       experiment_name: str,
-                                       holdout_dataset: Dataset,
-                                       target_column: str,
-                                       external_models: List[Tuple],
-                                       metric: metrics.Regression = metrics.Classification.AUC,
-                                       dataset: Dataset = None,
-                                       experiment_version_description: str = None) -> ExternalExperimentVersion:
+    def create_external_classification(
+        self,
+        experiment_name: str,
+        holdout_dataset: Dataset,
+        target_column: str,
+        external_models: List[Tuple],
+        metric: metrics.Regression = metrics.Classification.AUC,
+        dataset: Dataset = None,
+        experiment_version_description: str = None,
+    ) -> ExternalExperimentVersion:
         """ Create a tabular classification experiment version from external models
 
         Args:
             experiment_name (str): Name of the experiment to create
             holdout_dataset (:class:`.Dataset`): Reference to the holdout dataset object to use for as holdout dataset
-            target_column: The name of the target column for this experiment version
-            external_models (list(tuple)): the external models to add in the experiment version to create
+            target_column (str): The name of the target column for this experiment version
+            external_models (list(tuple)): The external models to add in the experiment version to create.
                 Each tuple contains 3 items describing an external model as follows:
-                - name of the model
-                - a path to the model in onnx format
-                - a path to a yaml file containing metadata about the model
-            metric (str, optional): Specific metric to use for the experiment (default: ``auc``)
+
+                    1) The name you want to give to the model
+                    2) The path to the model in onnx format
+                    3) The path to a yaml file containing metadata about the model
+            metric (:class:`.metrics.Classification`, optional): Specific metric to use for the experiment
+                (default: ``metrics.Classification.AUC``)
             dataset (:class:`.Dataset`, optional): Reference to the dataset object that
                 has been used to train the model (default: ``None``)
             experiment_version_description (str): Description of the experiment version to create
@@ -917,7 +955,8 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         if len(external_models) == 0:
             raise PrevisionException('You must provide at least one external model')
-        experiment = Experiment.new(self._id, 'external', experiment_name, DataType.Tabular, TypeProblem.Classification)
+        experiment = Experiment.new(self._id, 'external', experiment_name, DataType.Tabular,
+                                    TypeProblem.Classification)
         return ExternalExperimentVersion._fit(
             experiment.id,
             holdout_dataset,
@@ -928,26 +967,30 @@ class Project(ApiResource, UniqueResourceMixin):
             description=experiment_version_description,
         )
 
-    def create_external_multiclassification(self,
-                                            experiment_name: str,
-                                            holdout_dataset: Dataset,
-                                            target_column: str,
-                                            external_models: List[Tuple],
-                                            metric: metrics.Regression = metrics.MultiClassification.log_loss,
-                                            dataset: Dataset = None,
-                                            experiment_version_description: str = None) -> ExternalExperimentVersion:
+    def create_external_multiclassification(
+        self,
+        experiment_name: str,
+        holdout_dataset: Dataset,
+        target_column: str,
+        external_models: List[Tuple],
+        metric: metrics.Regression = metrics.MultiClassification.log_loss,
+        dataset: Dataset = None,
+        experiment_version_description: str = None,
+    ) -> ExternalExperimentVersion:
         """ Create a tabular multiclassification experiment version from external models
 
         Args:
             experiment_name (str): Name of the experiment to create
             holdout_dataset (:class:`.Dataset`): Reference to the holdout dataset object to use for as holdout dataset
-            target_column: The name of the target column for this experiment version
-            external_models (list(tuple)): the external models to add in the experiment version to create
+            target_column (str): The name of the target column for this experiment version
+            external_models (list(tuple)): The external models to add in the experiment version to create.
                 Each tuple contains 3 items describing an external model as follows:
-                - name of the model
-                - a path to the model in onnx format
-                - a path to a yaml file containing metadata about the model
-            metric (str, optional): Specific metric to use for the experiment (default: ``log_loss``)
+
+                    1) The name you want to give to the model
+                    2) The path to the model in onnx format
+                    3) The path to a yaml file containing metadata about the model
+            metric (:class:`.metrics.MultiClassification`, optional): Specific metric to use for the experiment
+                (default: ``metrics.MultiClassification.log_loss``)
             dataset (:class:`.Dataset`, optional): Reference to the dataset object that
                 has been used to train the model (default: ``None``)
             experiment_version_description (str): Description of the experiment version to create
